From 8d2ffb43db2a80254efb401d2f337f6404db8e03 Mon Sep 17 00:00:00 2001
From: romkatv <roman.perepelitsa@gmail.com>
Date: Wed, 31 Jul 2019 19:41:14 +0200
Subject: add "help" and "segment" commands to p10k

---
 config/p10k-classic.zsh | 4 ++--
 config/p10k-lean.zsh    | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

(limited to 'config')

diff --git a/config/p10k-classic.zsh b/config/p10k-classic.zsh
index 889d6618..baa380df 100644
--- a/config/p10k-classic.zsh
+++ b/config/p10k-classic.zsh
@@ -610,9 +610,9 @@ fi
   # prompt if `example` prompt segment is added to POWERLEVEL9K_LEFT_PROMPT_ELEMENTS or
   # POWERLEVEL9K_RIGHT_PROMPT_ELEMENTS. It displays an icon and orange text greeting the user.
   #
   # Type `p9k_prompt_segment -h` for documentation and a more sophisticated example.
   function prompt_example() {
-    p9k_prompt_segment -f 208 -i '⭐' -t 'hello, %n'
+    p10k segment -f 208 -i '⭐' -t 'hello, %n'
   }
 
   # User-defined prompt segments can be customized the same way as built-in segments.
@@ -610,9 +610,9 @@ fi
   # POWERLEVEL9K_RIGHT_PROMPT_ELEMENTS. It displays an icon and orange text greeting the user.
   #
-  # Type `p9k_prompt_segment -h` for documentation and a more sophisticated example.
+  # Type `p10k help segment` for documentation and a more sophisticated example.
   function prompt_example() {
diff --git a/config/p10k-lean.zsh b/config/p10k-lean.zsh
index 6914c474..e4451fc0 100644
--- a/config/p10k-lean.zsh
+++ b/config/p10k-lean.zsh
@@ -595,9 +595,9 @@ fi
   # prompt if `example` prompt segment is added to POWERLEVEL9K_LEFT_PROMPT_ELEMENTS or
   # POWERLEVEL9K_RIGHT_PROMPT_ELEMENTS. It displays an icon and orange text greeting the user.
   #
   # Type `p9k_prompt_segment -h` for documentation and a more sophisticated example.
   function prompt_example() {
-    p9k_prompt_segment -f 208 -i '⭐' -t 'hello, %n'
+    p10k segment -f 208 -i '⭐' -t 'hello, %n'
   }
 
   # User-defined prompt segments can be customized the same way as built-in segments.
@@ -595,9 +595,9 @@ fi
   # POWERLEVEL9K_RIGHT_PROMPT_ELEMENTS. It displays an icon and orange text greeting the user.
   #
-  # Type `p9k_prompt_segment -h` for documentation and a more sophisticated example.
+  # Type `p10k help segment` for documentation and a more sophisticated example.
   function prompt_example() {
-- 
cgit v1.2.3